import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import { writeFile } from 'node:fs/promises'
import path from 'path'
import fs from 'fs/promises'
import prisma from '../../../utilities/Prisma'

interface ISpriteData {
  [key: string]: Buffer
}

/**
 * Handle game master upload sprite event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:upload', async (data: ISpriteData, callback: (response: boolean) => void) => {
    try {
      if (socket.character?.role !== 'gm') {
        callback(false)
        return
      }

      const public_folder = path.join(process.cwd(), 'public', 'sprites')

      // Ensure the folder exists
      await fs.mkdir(public_folder, { recursive: true })

      const uploadPromises = Object.entries(data).map(async ([key, spriteData]) => {
        const sprite = await prisma.sprite.create({
          data: {
            name: 'New sprite'
          }
        })
        const uuid = sprite.id
        const filename = `${uuid}.png`
        const finalFilePath = path.join(public_folder, filename)
        await writeFile(finalFilePath, spriteData)
      })

      await Promise.all(uploadPromises)

      callback(true)
    } catch (error) {
      console.error('Error uploading sprite:', error)
      callback(false)
    }
  })
}
